@@ -55,8 +55,8 @@ class GitOpen(object):
         origin_line = re.sub("^origin", "", origin_line)
 
         # Remove protocols
-        origin_line = re.sub("http://", "", origin_line)
-        origin_line = re.sub("ssh://", "", origin_line)
+        origin_line = re.sub("[A-Za-z0-9][A-Za-z0-9+.-]*://", "", origin_line)
+        origin_line = re.sub("[A-Za-z0-9][A-Za-z0-9+.-]*@", "", origin_line)
 
         origin_line = re.sub("\.git.*$", "", origin_line)
         origin_line = re.sub("\(.*\)", "", origin_line)
@@ -86,22 +86,14 @@ class GitOpen(object):
         'github.com:username/git_open.git' ->
         https://github.com/username/git_open
         """
-        if filtered_origin_string.startswith("http"):
-            return filtered_origin_string
-
-        elif filtered_origin_string.startswith("git@"):
-            filtered_origin_string = GitOpen._handle_ports_in_url(
-                filtered_origin_string
-            )
-            url = filtered_origin_string.replace("git@", "https://")
-            return url
-
-        else:
+        if filtered_origin_string.startswith("git@"):
             raise NotImplementedError(
                 "The filtered origin string did not start as expected",
                 filtered_origin_string,
             )
 
+        return "https://" + GitOpen._handle_ports_in_url(filtered_origin_string)
+
     def add_commit_to_url(self):
         current_commit_hash = GitOpen.get_current_commit_hash()
         self.url += "/commit/%s" % current_commit_hash
